import { Component, ChangeDetectionStrategy, inject, OnInit, signal, ChangeDetectorRef } from '@angular/core';
import { CommonModule } from '@angular/common';
import { NzTableModule } from 'ng-zorro-antd/table';
import { NzButtonModule } from 'ng-zorro-antd/button';
import { NzIconModule } from 'ng-zorro-antd/icon';
import { NzTagModule } from 'ng-zorro-antd/tag';
import { NzCardModule } from 'ng-zorro-antd/card';
import { NzDropDownModule } from 'ng-zorro-antd/dropdown';
import { NzMenuModule } from 'ng-zorro-antd/menu';
import { NzModalModule } from 'ng-zorro-antd/modal';
import { NzMessageModule } from 'ng-zorro-antd/message';
import { NzMessageService } from 'ng-zorro-antd/message';
import { NzSpinModule } from 'ng-zorro-antd/spin';
import { NzDescriptionsModule } from 'ng-zorro-antd/descriptions';
import { Job, JobFormData } from '../../../shared/data-access/interface/job.interface';
import { JobStateService } from '../../../shared/data-access/service/job-state.service';
import { JobApiService } from '../../../shared/data-access/service/job-api.service';
import { JobFormComponent } from '../../components/job-form/job-form.component';

@Component({
  selector: 'admin-dashboard',
  standalone: true,
  imports: [
    CommonModule,
    NzTableModule,
    NzButtonModule,
    NzIconModule,
    NzTagModule,
    NzCardModule,
    NzDropDownModule,
    NzMenuModule,
    NzModalModule,
    NzMessageModule,
    NzSpinModule,
    NzDescriptionsModule,
    JobFormComponent
  ],
  template: `
    <div class="tw-p-6">
      <!-- Header Section -->
      <div class="tw-flex tw-justify-between tw-items-center tw-mb-6">
        <div>
          <h1 class="tw-text-3xl tw-font-bold tw-text-gray-900 tw-mb-2">Job Management Dashboard</h1>
        </div>
        <button 
          nz-button 
          nzType="primary" 
          nzSize="large"
          (click)="openAddJobModal()"
          class="tw-bg-blue-600 hover:tw-bg-blue-700">
          <span nz-icon nzType="plus" class="tw-mr-1 tw-relative tw--top-[2px]"></span>
          Add
        </button>
      </div>

      <!-- Jobs Table -->
      <nz-card [nzBordered]="false" class="tw-shadow-lg">
        <div class="tw-flex tw-justify-between tw-items-center tw-mb-4">
          <h2 class="tw-text-xl tw-font-semibold tw-text-gray-900">Recent Job Postings</h2>
          <button nz-button nzType="default" (click)="refreshJobs()" [nzLoading]="jobStateService.loading()">
            <span nz-icon nzType="reload" class="tw-relative tw--top-[3px]"></span>
            Refresh
          </button>
        </div>

        <nz-spin [nzSpinning]="jobStateService.loading()">
          <nz-table 
            #jobsTable 
            [nzData]="jobStateService.jobs()" 
            [nzPageSize]="10"
            [nzShowSizeChanger]="true"
            [nzShowQuickJumper]="true"
            [nzShowTotal]="totalTemplate"
            class="tw-w-full">
            
            <thead>
              <tr>
                <th nzWidth="80px">STT</th>
                <th nzWidth="300px">Name</th>
                <th nzWidth="120px">Type</th>
                <th nzWidth="150px">Location</th>
                <th nzWidth="120px" nzAlign="center">Action</th>
              </tr>
            </thead>
            
            <tbody>
              @for (job of jobsTable.data; track job.id; let i = $index) {
                <tr>
                  <td>
                    <span class="tw-font-medium tw-text-gray-900">{{ i + 1 }}</span>
                  </td>
                  
                  <td>
                    <div class="tw-font-medium tw-text-gray-900">{{ job.title }}</div>
                    <div class="tw-text-sm tw-text-gray-500">{{ job.company }}</div>
                  </td>
                  
                  <td>
                    <nz-tag [nzColor]="getJobTypeColor(job.type)">
                      {{ job.type }}
                    </nz-tag>
                  </td>
                  
                  <td>
                    <span class="tw-text-gray-700">{{ job.location }}</span>
                  </td>
                  
                  <td nzAlign="center">
                    <button 
                      nz-dropdown 
                      [nzDropdownMenu]="menu" 
                      nzPlacement="bottomRight"
                      nz-button 
                      nzType="text" 
                      nzSize="small">
                      <span nz-icon nzType="more" nzTheme="outline"></span>
                    </button>
                    
                    <nz-dropdown-menu #menu="nzDropdownMenu">
                      <ul nz-menu>
                        <li nz-menu-item (click)="viewJobDetail(job)">
                          <span nz-icon nzType="eye" class="tw-mr-2"></span>
                          View Details
                        </li>
                        <li nz-menu-item (click)="editJob(job)">
                          <span nz-icon nzType="edit" class="tw-mr-2"></span>
                          Edit Job
                        </li>
                        <li nz-menu-divider></li>
                        <li nz-menu-item (click)="confirmDeleteJob(job)" class="tw-text-red-600">
                          <span nz-icon nzType="delete" class="tw-mr-2"></span>
                          Delete Job
                        </li>
                      </ul>
                    </nz-dropdown-menu>
                  </td>
                </tr>
              }
            </tbody>
          </nz-table>
        </nz-spin>

        <ng-template #totalTemplate let-total>
          Total {{ total }} jobs
        </ng-template>
      </nz-card>
    </div>

    <!-- Add/Edit Job Modal -->
    @if (showJobFormModal) {
      <nz-modal 
        [(nzVisible)]="showJobFormModal"
        [nzTitle]="isEditMode ? 'Edit Job' : 'Add New Job'"
        [nzWidth]="900"
        [nzFooter]="null"
        (nzOnCancel)="closeJobFormModal()">
        
        <div *nzModalContent>
          <job-form 
            [job]="selectedJob"
            [loading]="jobFormLoading"
            (formSubmit)="onJobFormSubmit($event)"
            (formCancel)="closeJobFormModal()">
          </job-form>
        </div>
      </nz-modal>
    }

    <!-- Job Detail Modal -->
    @if (showDetailModal && selectedJob) {
      <nz-modal 
        [(nzVisible)]="showDetailModal"
        [nzTitle]="'Job Details'"
        [nzWidth]="800"
        [nzFooter]="null"
        (nzOnCancel)="closeDetailModal()">
        
        <div *nzModalContent>
          <!-- Header -->
          <div class="tw-mb-6">
            <h2 class="tw-text-2xl tw-font-bold tw-text-gray-900 tw-mb-2">{{ selectedJob.title }}</h2>
            <div class="tw-flex tw-flex-wrap tw-items-center tw-gap-4 tw-text-sm tw-text-gray-600">
              <span class="tw-flex tw-items-center tw-gap-1">
                <span nz-icon nzType="bank" class="tw-text-blue-500"></span>
                <a [href]="selectedJob.company_url" target="_blank" class="tw-text-blue-600 hover:tw-text-blue-800">
                  {{ selectedJob.company }}
                </a>
              </span>
              <span class="tw-flex tw-items-center tw-gap-1">
                <span nz-icon nzType="environment" class="tw-text-green-500"></span>
                {{ selectedJob.location }}
              </span>
              <span class="tw-flex tw-items-center tw-gap-1">
                <span nz-icon nzType="calendar" class="tw-text-purple-500"></span>
                {{ formatDate(selectedJob.created_at) }}
              </span>
            </div>
          </div>

          <!-- Type Tag -->
          <div class="tw-mb-6">
            <nz-tag [nzColor]="getJobTypeColor(selectedJob.type)">
              {{ selectedJob.type }}
            </nz-tag>
          </div>

          <!-- Job Information -->
          <nz-descriptions nzBordered nzSize="middle" class="tw-mb-6">
            <nz-descriptions-item nzTitle="Job ID">{{ selectedJob.id }}</nz-descriptions-item>
            <nz-descriptions-item nzTitle="Type">
              <nz-tag [nzColor]="getJobTypeColor(selectedJob.type)">{{ selectedJob.type }}</nz-tag>
            </nz-descriptions-item>
            
            <nz-descriptions-item nzTitle="Company">
              @if (selectedJob.company_logo) {
                <div class="tw-flex tw-items-center tw-gap-2">
                  <img [src]="selectedJob.company_logo" [alt]="selectedJob.company" class="tw-w-6 tw-h-6 tw-rounded">
                  <a [href]="selectedJob.company_url" target="_blank" class="tw-text-blue-600 hover:tw-text-blue-800">
                    {{ selectedJob.company }}
                  </a>
                </div>
              } @else {
                <a [href]="selectedJob.company_url" target="_blank" class="tw-text-blue-600 hover:tw-text-blue-800">
                  {{ selectedJob.company }}
                </a>
              }
            </nz-descriptions-item>
            <nz-descriptions-item nzTitle="Location">{{ selectedJob.location }}</nz-descriptions-item>
            <nz-descriptions-item nzTitle="Created">{{ formatDate(selectedJob.created_at) }}</nz-descriptions-item>
          </nz-descriptions>

          <!-- Description -->
          <div class="tw-mb-6">
            <h3 class="tw-text-lg tw-font-semibold tw-text-gray-900 tw-mb-3">Job Description</h3>
            <div class="tw-prose tw-prose-sm tw-max-w-none" [innerHTML]="selectedJob.description"></div>
          </div>

          <!-- How to Apply -->
          @if (selectedJob.how_to_apply) {
            <div class="tw-mb-6">
              <h3 class="tw-text-lg tw-font-semibold tw-text-gray-900 tw-mb-3">How to Apply</h3>
              <div class="tw-prose tw-prose-sm tw-max-w-none" [innerHTML]="selectedJob.how_to_apply"></div>
            </div>
          }

          <!-- Actions -->
          <div class="tw-flex tw-justify-end tw-space-x-4 tw-pt-4 tw-border-t tw-border-gray-200">
            <button 
              nz-button 
              nzType="default" 
              (click)="closeDetailModal()">
              Close
            </button>
            <button 
              nz-button 
              nzType="primary" 
              (click)="onEditJobFromDetail(selectedJob)">
              <span nz-icon nzType="edit"></span>
              Edit Job
            </button>
          </div>
        </div>
      </nz-modal>
    }
  `,
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class DashboardComponent implements OnInit {
  private readonly cdr = inject(ChangeDetectorRef);
  readonly jobStateService = inject(JobStateService);
  private readonly jobApiService = inject(JobApiService);
  private readonly messageService = inject(NzMessageService);

  showJobFormModal: boolean = false;
  showDetailModal: boolean = false;
  jobFormLoading = signal<boolean>(false);
  isEditMode: boolean = false;
  selectedJob: Job | null = null;

  ngOnInit(): void {
    this.loadInitialData();
  }

  private loadInitialData(): void {
    this.jobStateService.loadJobs().subscribe({
      next: () => {
        console.log('Jobs loaded successfully from API');
      },
      error: (error) => {
        console.error('Failed to load jobs from API:', error);
        this.messageService.error(`Failed to load jobs: ${error.message}`);
      }
    });

    this.jobStateService.loadJobStats().subscribe({
      next: () => {
        console.log('Job stats loaded successfully from API');
      },
      error: (error) => {
        console.warn('Failed to load job stats from API:', error);
      }
    });
  }

  // Job actions
  openAddJobModal(): void {
    this.isEditMode = false;
    this.selectedJob = null;
    this.showJobFormModal = true;
    this.cdr.markForCheck();
  }

  editJob(job: Job): void {
    this.isEditMode = true;
    this.selectedJob = job;
    this.showJobFormModal = true;
    this.cdr.markForCheck();
  }

  viewJobDetail(job: Job): void {
    this.selectedJob = job;
    this.showDetailModal = true;
    console.log('Opening job detail for:', job.title);
    this.cdr.markForCheck();
  }

  confirmDeleteJob(job: Job): void {
    const modalRef = this.messageService.loading('Preparing to delete job...', { nzDuration: 0 });
    
    setTimeout(() => {
      this.messageService.remove(modalRef.messageId);
      
      if (confirm(`Are you sure you want to delete the job "${job.title}"? This action cannot be undone.`)) {
        this.deleteJob(job);
      }
    }, 500);
  }

  deleteJob(job: Job): void {
    this.jobApiService.deleteJob(job.id).subscribe({
      next: () => {
        this.jobStateService.removeJob(job.id);
        this.messageService.success(`Job "${job.title}" deleted successfully`);
        this.cdr.markForCheck();
      },
      error: (error) => {
        this.messageService.error(`Failed to delete job: ${error.message}`);
        this.cdr.markForCheck();
      }
    });
  }

  refreshJobs(): void {
    this.jobStateService.loadJobs().subscribe({
      next: () => {
        this.messageService.success('Jobs refreshed successfully');
      },
      error: (error) => {
        this.messageService.error(`Failed to refresh jobs: ${error.message}`);
      }
    });
  }

  // Modal handlers
  closeJobFormModal(): void {
    this.showJobFormModal = false;
    this.selectedJob = null;
    this.isEditMode = false;
    this.jobFormLoading.set(false);
    this.cdr.markForCheck();
  }

  closeDetailModal(): void {
    console.log('Closing detail modal...');
    this.showDetailModal = false;
    this.selectedJob = null;
    console.log('Detail modal closed, state reset');
    this.cdr.markForCheck();
  }

  onEditJobFromDetail(job: Job): void {
    // Close detail modal and open edit modal
    this.showDetailModal = false;
    this.isEditMode = true;
    this.selectedJob = job;
    this.showJobFormModal = true;
  }

  onJobFormSubmit(jobData: JobFormData): void {
    this.jobFormLoading.set(true);

    if (this.isEditMode && this.selectedJob) {
      // Update job
      this.jobApiService.updateJob({ id: this.selectedJob.id, job: jobData }).subscribe({
        next: (response) => {
          if (response.success) {
            this.jobStateService.updateJob(response.responseData.job);
            this.messageService.success(`Job "${response.responseData.job.title}" updated successfully`);
            this.closeJobFormModal();
          } else {
            this.messageService.error(`Failed to update job: ${response.message}`);
            this.jobFormLoading.set(false);
          }
        },
        error: (error) => {
          this.messageService.error(`Failed to update job: ${error.message}`);
          this.jobFormLoading.set(false);
        }
      });
    } else {
      // Create new job
      this.jobApiService.createJob({ job: jobData }).subscribe({
        next: (response) => {
          if (response.success) {
            this.jobStateService.addJob(response.responseData.job);
            this.messageService.success(`Job "${response.responseData.job.title}" created successfully`);
            this.closeJobFormModal();
          } else {
            this.messageService.error(`Failed to create job: ${response.message}`);
            this.jobFormLoading.set(false);
          }
        },
        error: (error) => {
          this.messageService.error(`Failed to create job: ${error.message}`);
          this.jobFormLoading.set(false);
        }
      });
    }
  }

  getJobDescription(description: string): string {
    const stripped = description.replace(/<[^>]*>/g, '');
    return stripped.length > 100 ? stripped.substring(0, 100) + '...' : stripped;
  }

  getJobTypeColor(type: string): string {
    switch (type) {
      case 'Full Time': return 'blue';
      case 'Part Time': return 'cyan';
      case 'Remote': return 'purple';
      default: return 'default';
    }
  }

  formatDate(dateString: string): string {
    return new Date(dateString).toLocaleDateString('en-US', {
      year: 'numeric',
      month: 'short',
      day: 'numeric'
    });
  }
}
