import { CommonModule } from '@angular/common';
import { ChangeDetectionStrategy, Component, OnInit, inject, ChangeDetectorRef } from '@angular/core';
import { Router } from '@angular/router';
import { AuthService } from '../../../../../shared/data-access/service/auth.service';
import { Observable, finalize } from 'rxjs';
import { AuthState } from '../../../../../shared/data-access/interface/auth.interface';
import { NzLayoutModule } from 'ng-zorro-antd/layout';
import { NzIconModule } from 'ng-zorro-antd/icon';
import { NzCardModule } from 'ng-zorro-antd/card';
import { NzAvatarModule } from 'ng-zorro-antd/avatar';
import { NzTagModule } from 'ng-zorro-antd/tag';
import { NzButtonModule } from 'ng-zorro-antd/button';

@Component({
  selector: 'meu-header',
  standalone: true,
  imports: [
    CommonModule,
    NzLayoutModule,
    NzIconModule,
    NzCardModule,
    NzAvatarModule,
    NzTagModule,
    NzButtonModule
  ],
  templateUrl: './header.component.html',
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class HeaderComponent implements OnInit {
  private authService = inject(AuthService);
  private router = inject(Router);
  private cdr = inject(ChangeDetectorRef);

  authState$: Observable<AuthState> = this.authService.authState$;
  isLoggingOut = false;

  ngOnInit(): void {}

  onLogout(): void {
    if (this.isLoggingOut) return;
    
    this.isLoggingOut = true;
    this.cdr.markForCheck();

    this.authService.logout()
      .pipe(
        finalize(() => {
          this.isLoggingOut = false;
          this.cdr.markForCheck();
          this.router.navigate(['/login']);
        })
      )
      .subscribe();
  }
}
