import { Pagination } from './common.interface';

export interface Job {
  id: string;
  title: string;
  description: string;
  company: string;
  company_url: string;
  location: string;
  type: JobType;
  created_at: string;
  how_to_apply?: string; 
  company_logo?: string | null; 
}

export type JobLocation = 'Viet Nam' | 'Lao' | 'Campuchia';

export type JobType = 'Full Time' | 'Part Time' | 'Remote';

export interface JobFormData {
  title: string;
  description: string;
  company: string;
  company_url: string;
  location: JobLocation; 
  type: JobType;
  how_to_apply?: string; 
  company_logo?: string | null; 
}

export interface CreateJobRequest {
  job: JobFormData;
}

export interface UpdateJobRequest {
  id: string;
  job: Partial<JobFormData>;
}

export interface JobResponse {
  message: string;
  responseData: {
    job: Job;
  };
  success: boolean;
  status: number;
}

export interface JobListResponse {
  message: string;
  responseData: {
    jobs: Job[];
    total: number;
    page: number;
    limit: number;
  };
  success: boolean;
  status: number;
}

export interface JobStats {
  totalJobs: number;
  companiesCount: number;
}

export interface JobFilter {
  type?: JobType;
  company?: string;
  location?: JobLocation;
  search?: string;
}

export interface JobPagination extends Pagination {}
