import { Injectable, inject } from '@angular/core';
import { Observable } from 'rxjs';
import { 
  Job, 
  JobFormData, 
  JobStats 
} from '../interface/job.interface';
import { JobApiService } from './job-api.service';
import { JobStateService } from './job-state.service';

@Injectable({ providedIn: 'root' })
export class JobService {
  private readonly jobApiService = inject(JobApiService);
  private readonly jobStateService = inject(JobStateService);

  // Expose state
  jobs = this.jobStateService.jobs;
  loading = this.jobStateService.loading;
  error = this.jobStateService.error;
  stats = this.jobStateService.stats;

  // Computed stats
  totalJobs = this.jobStateService.totalJobs;
  companiesCount = this.jobStateService.companiesCount;

  constructor() {
    // Load jobs from API on service initialization
    this.loadJobs().subscribe({
      next: () => {
        console.log('Initial jobs loaded from API');
      },
      error: (error) => {
        console.error('Failed to load initial jobs from API:', error);
      }
    });
  }

  // Main API methods
  loadJobs = (): Observable<Job[]> =>
    this.jobStateService.loadJobs();

  loadJobStats = (): Observable<JobStats | null> =>
    this.jobStateService.loadJobStats();

  // Helper methods for job data formatting
  formatJobData = (formData: JobFormData): JobFormData => {
    return {
      ...formData,
      title: formData.title.trim(),
      description: formData.description.trim(),
      company: formData.company.trim(),
      company_url: formData.company_url.trim()
    };
  };
}
