import { Injectable } from '@angular/core';
import { UserInfo } from '../interface/auth.interface';

@Injectable({ providedIn: 'root' })
export class StorageService {
  private readonly TOKEN_KEY = 'token';
  private readonly USER_KEY = 'user_info';
  private readonly REFRESH_KEY = 'refresh_token';
  private readonly EXPIRY_KEY = 'token_expiration';

  // Token operations
  setToken = (token: string): void => localStorage.setItem(this.TOKEN_KEY, token);
  getToken = (): string | null => localStorage.getItem(this.TOKEN_KEY);
  removeToken = (): void => localStorage.removeItem(this.TOKEN_KEY);

  // User operations
  setUser = (user: UserInfo): void => localStorage.setItem(this.USER_KEY, JSON.stringify(user));
  getUser = (): UserInfo | null => {
    const userStr = localStorage.getItem(this.USER_KEY);
    if (!userStr) return null;
    
    try {
      return JSON.parse(userStr);
    } catch {
      return null;
    }
  };
  removeUser = (): void => localStorage.removeItem(this.USER_KEY);

  // Expiry operations
  setExpiry = (expiry: number): void => localStorage.setItem(this.EXPIRY_KEY, expiry.toString());
  getExpiry = (): number | null => {
    const expiry = localStorage.getItem(this.EXPIRY_KEY);
    return expiry ? parseInt(expiry, 10) : null;
  };
  removeExpiry = (): void => localStorage.removeItem(this.EXPIRY_KEY);

  // Refresh token operations
  setRefreshToken = (token: string): void => localStorage.setItem(this.REFRESH_KEY, token);
  getRefreshToken = (): string | null => localStorage.getItem(this.REFRESH_KEY);
  removeRefreshToken = (): void => localStorage.removeItem(this.REFRESH_KEY);

  // Batch operations
  storeAuthData = (token: string, user: UserInfo, expiry: number): void => {
    this.setToken(token);
    this.setUser(user);
    this.setExpiry(expiry);
  };

  clearAllAuth = (): void => {
    this.removeToken();
    this.removeUser();
    this.removeExpiry();
    this.removeRefreshToken();
  };

  // Validation
  hasValidAuthData = (): boolean => {
    const token = this.getToken();
    const user = this.getUser();
    return Boolean(token && user);
  };
}
